API Reference
=============

.. automodule:: anchorite
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: anchorite.orchestrator
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: anchorite.providers
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: anchorite.document
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: anchorite.types
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: anchorite.bbox_alignment
   :members:
   :undoc-members:
   :show-inheritance:
